@@ -3,27 +3,38 @@ import pytest
 
 import astropy
 import astropy.units as u
-from astropy.tests.helper import quantity_allclose, assert_quantity_allclose
-from astropy.coordinates import (SkyCoord, get_body_barycentric, Angle,
-                                 ConvertError, Longitude, CartesianRepresentation,
-                                 get_body_barycentric_posvel,
-                                 CartesianDifferential, SphericalDifferential)
-# Versions of Astropy that do not have HeliocentricMeanEcliptic have the same frame
-# with the misleading name HeliocentricTrueEcliptic
-try:
-    from astropy.coordinates import HeliocentricMeanEcliptic
-except ImportError:
-    from astropy.coordinates import HeliocentricTrueEcliptic as HeliocentricMeanEcliptic
-
+from astropy.constants import c as speed_of_light
+from astropy.coordinates import (
+    ICRS,
+    Angle,
+    CartesianDifferential,
+    CartesianRepresentation,
+    ConvertError,
+    HeliocentricMeanEcliptic,
+    Longitude,
+    SkyCoord,
+    SphericalDifferential,
+    get_body_barycentric,
+    get_body_barycentric_posvel,
+)
+from astropy.tests.helper import assert_quantity_allclose, quantity_allclose
 from astropy.time import Time
 
-from sunpy.coordinates import (Helioprojective, HeliographicStonyhurst,
-                               HeliographicCarrington, Heliocentric,
-                               HeliocentricEarthEcliptic, GeocentricSolarEcliptic,
-                               HeliocentricInertial, GeocentricEarthEquatorial,
-                               get_earth)
-from sunpy.coordinates import sun
+from sunpy.coordinates import (
+    GeocentricEarthEquatorial,
+    GeocentricSolarEcliptic,
+    Heliocentric,
+    HeliocentricEarthEcliptic,
+    HeliocentricInertial,
+    HeliographicCarrington,
+    HeliographicStonyhurst,
+    Helioprojective,
+    sun,
+)
 from sunpy.coordinates.frames import _J2000
+from sunpy.coordinates.transformations import transform_with_sun_center
+from sunpy.sun.constants import radius as _RSUN
+from sunpy.sun.constants import sidereal_rotation_rate
 from sunpy.time import parse_time
 
 
@@ -163,7 +174,7 @@ def test_hgs_hgc_roundtrip():
     obstime = "2011-01-01"
 
     hgsin = HeliographicStonyhurst(lat=10*u.deg, lon=20*u.deg, obstime=obstime)
-    hgcout = hgsin.transform_to(HeliographicCarrington(obstime=obstime))
+    hgcout = hgsin.transform_to(HeliographicCarrington(observer='earth', obstime=obstime))
 
     assert_quantity_allclose(hgsin.lat, hgcout.lat)
     assert_quantity_allclose(hgsin.lon + sun.L0(obstime), hgcout.lon)
@@ -224,8 +235,9 @@ def test_hgs_cartesian_rep_to_hgc():
     hgscoord_sph = hgscoord_cart.copy()
     hgscoord_sph.representation_type = 'spherical'
     # HGC
-    hgccoord_cart = hgscoord_cart.transform_to(HeliographicCarrington(obstime=obstime))
-    hgccoord_sph = hgscoord_sph.transform_to(HeliographicCarrington(obstime=obstime))
+    hgcframe = HeliographicCarrington(observer='earth', obstime=obstime)
+    hgccoord_cart = hgscoord_cart.transform_to(hgcframe)
+    hgccoord_sph = hgscoord_sph.transform_to(hgcframe)
     assert_quantity_allclose(hgccoord_cart.lat, hgccoord_sph.lat)
     assert_quantity_allclose(hgccoord_cart.lon, hgccoord_sph.lon)
     assert_quantity_allclose(hgccoord_cart.radius, hgccoord_sph.radius)
@@ -328,12 +340,36 @@ def test_hgs_hgs():
 def test_hgc_hgc():
     # Test HGC loopback transformation
     obstime = Time('2001-01-01')
-    old = SkyCoord(90*u.deg, 10*u.deg, 1*u.AU, frame=HeliographicCarrington(obstime=obstime))
-    new = old.transform_to(HeliographicCarrington(obstime=obstime + 1*u.day))
+    old = SkyCoord(90*u.deg, 10*u.deg, 1*u.AU, frame=HeliographicCarrington(observer='earth',
+                                                                            obstime=obstime))
+    new = old.transform_to(HeliographicCarrington(observer='earth', obstime=obstime + 1*u.day))
 
-    assert_quantity_allclose(new.lon, old.lon - 14.1844*u.deg, atol=1e-4*u.deg)  # solar rotation
-    assert_quantity_allclose(new.lat, old.lat, atol=1e-4*u.deg)
-    assert_quantity_allclose(new.radius, old.radius, atol=1e-5*u.AU)
+    assert_quantity_allclose(new.lon, 75.815607 * u.deg, atol=1e-7*u.deg)  # solar rotation
+    # These are not equal to the old values, because the coordinates stay fixed
+    # in inertial space, whilst the frame (fixed to the center of the Sun)
+    # moves slightly.
+    assert_quantity_allclose(new.lat, 9.999963 * u.deg, atol=1e-7*u.deg)
+    assert_quantity_allclose(new.radius, 1.000009 * u.AU, atol=1e-7*u.AU)
+
+
+def test_hgc_hgc_different_observers():
+    obstime = Time('2001-01-01')
+    hgc_earth = HeliographicCarrington(observer='earth', obstime=obstime)
+    hgc_mars = HeliographicCarrington(observer='mars', obstime=obstime)
+    hgc_sun = HeliographicCarrington(observer='sun', obstime=obstime)
+
+    sc = SkyCoord(10*u.deg, 20*u.deg, 1*u.AU, frame=HeliographicStonyhurst(obstime=obstime))
+    sc_hgc_earth = sc.transform_to(hgc_earth)
+
+    sc_hgc_mars = sc_hgc_earth.transform_to(hgc_mars)
+
+    sc_hgc_sun = sc_hgc_mars.transform_to(hgc_sun)
+
+    ltt_earth = hgc_earth.observer.radius / speed_of_light
+    assert_quantity_allclose(sc_hgc_earth.lon - sc_hgc_sun.lon, ltt_earth * sidereal_rotation_rate)
+
+    ltt_mars = hgc_mars.observer.radius / speed_of_light
+    assert_quantity_allclose(sc_hgc_mars.lon - sc_hgc_sun.lon, ltt_mars * sidereal_rotation_rate)
 
 
 def test_hcc_hcc():
@@ -422,9 +458,7 @@ def test_hgs_hcrs_sunspice():
 def test_hgs_hgc_sunspice():
     # Compare our HGS->HGC transformation against SunSPICE
     # "HEQ" is another name for HEEQ, which is equivalent to Heliographic Stonyhurst
-    # "Carrington" is offset by 0.076 degrees in longitude from our Heliographic Carrington (HGC)
-    #   because "Carrington" does not include light travel time to the observer, while our
-    #   HGC includes the light travel time to Earth (see Seidelmann et al. 2007).
+    # "Carrington" does not include light travel time to the observer, which our HGC includes
     #
     # IDL> coord = [1.d, 0.d, 10.d]
     # IDL> convert_sunspice_lonlat, '2019-06-01', coord, 'HEQ', 'Carrington', /au, /degrees
@@ -432,9 +466,12 @@ def test_hgs_hgc_sunspice():
     #        1.0000000       16.688242       10.000000
 
     old = SkyCoord(0*u.deg, 10*u.deg, 1*u.AU, frame=HeliographicStonyhurst(obstime='2019-06-01'))
-    new = old.heliographic_carrington
+    new = old.transform_to(HeliographicCarrington(observer='earth'))
 
-    assert_quantity_allclose(new.lon, 16.688242*u.deg + 0.076*u.deg, atol=1e-2*u.arcsec, rtol=0)
+    # Calculate the difference in longitude due to light travel time from the Sun to the Earth
+    delta_lon = sidereal_rotation_rate * (sun.earth_distance(old.obstime) - _RSUN) / speed_of_light
+
+    assert_quantity_allclose(new.lon, 16.688242*u.deg + delta_lon, atol=1e-2*u.arcsec, rtol=0)
     assert_quantity_allclose(new.lat, old.lat)
     assert_quantity_allclose(new.radius, old.radius)
 
@@ -509,7 +546,8 @@ def test_velocity_hgs_hgc():
 
     # The induced velocity in HGC should be entirely longitudinal, and approximately equal to one
     # full rotation every mean synodic period (27.2753 days)
-    new = coord.heliographic_carrington
+    hgc_frame = HeliographicCarrington(observer='earth', obstime=obstime)
+    new = coord.transform_to(hgc_frame)
     new_vel = new.data.differentials['s'].represent_as(SphericalDifferential, new.data)
     assert_quantity_allclose(new_vel.d_lon, -360*u.deg / (27.27253*u.day), rtol=1e-2)
     assert_quantity_allclose(new_vel.d_lat, 0*u.deg/u.s)
@@ -715,13 +753,25 @@ def test_array_obstime():
     assert isinstance(t2.frame, Helioprojective)
 
 
-_frameset1 = [HeliographicStonyhurst, HeliographicCarrington, HeliocentricInertial]
-_frameset2 = [Heliocentric, Helioprojective]
+_frames_wo_observer = [HeliographicStonyhurst, HeliocentricInertial,
+                       HeliocentricEarthEcliptic, GeocentricSolarEcliptic,
+                       GeocentricEarthEquatorial]
 
 
-@pytest.mark.parametrize("start_class", _frameset1 + _frameset2)
-@pytest.mark.parametrize("end_class", _frameset1)
-def test_no_obstime_on_one_end(start_class, end_class):
+@pytest.mark.parametrize("frame_class", _frames_wo_observer)
+def test_convert_error_with_no_obstime(frame_class):
+    # For most transformations, we do not allow `obstime` to be `None`
+    frame = frame_class(CartesianRepresentation(0, 0, 0)*u.km, obstime=None)
+
+    with pytest.raises(ConvertError, match=r".*obstime.*"):
+        ICRS(0*u.deg, 0*u.deg, 0*u.AU).transform_to(frame)
+
+    with pytest.raises(ConvertError, match=r".*obstime.*"):
+        frame.transform_to(ICRS)
+
+
+# Convenience function to check whether a transformation succeeds if the target `obstime` is `None`
+def assert_no_obstime_on_target_end(start_class, end_class):
     start_obstime = Time("2001-01-01")
 
     if hasattr(start_class, 'observer'):
@@ -732,3 +782,85 @@ def test_no_obstime_on_one_end(start_class, end_class):
 
     result = coord.transform_to(end_class)
     assert result.obstime == start_obstime
+
+
+# We currently allow the target `obstime` to be `None` for the transformation subgraph
+# below `HeliographicStonyhurst`, but this may change in the future
+_frameset1 = [HeliographicStonyhurst, HeliocentricInertial]
+_frameset2 = [HeliographicCarrington, Heliocentric, Helioprojective]
+
+
+@pytest.mark.parametrize("start_class", _frameset1 + _frameset2)
+@pytest.mark.parametrize("end_class", _frameset1)
+def test_no_obstime_on_target_end_hgs_subgraph(start_class, end_class):
+    assert_no_obstime_on_target_end(start_class, end_class)
+
+
+# We currently allow the target `obstime` to be `None` for the transformation subgraph
+# below `HeliocentricEarthEcliptic`, but this may change in the future
+_frameset3 = [HeliocentricEarthEcliptic, GeocentricSolarEcliptic]
+
+
+@pytest.mark.parametrize("start_class", _frameset3)
+@pytest.mark.parametrize("end_class", _frameset3)
+def test_no_obstime_on_target_end_hee_subgraph(start_class, end_class):
+    assert_no_obstime_on_target_end(start_class, end_class)
+
+
+def test_transform_with_sun_center():
+    sun_center = SkyCoord(0*u.deg, 0*u.deg, 0*u.AU,
+                          frame=HeliographicStonyhurst(obstime="2001-01-01"))
+
+    with transform_with_sun_center():
+        result1 = sun_center.transform_to(HeliographicStonyhurst(obstime="2001-02-01"))
+
+    # The coordinate should stay pointing at Sun center
+    assert_quantity_allclose(result1.lon, sun_center.lon)
+    assert_quantity_allclose(result1.lat, sun_center.lat)
+    assert_quantity_allclose(result1.radius, sun_center.radius)
+
+    other = SkyCoord(10*u.deg, 20*u.deg, 1*u.AU,
+                     frame=HeliographicStonyhurst(obstime="2001-01-01"))
+
+    with transform_with_sun_center():
+        result2 = other.transform_to(HeliographicCarrington(observer='earth', obstime="2001-02-01"))
+
+    # The coordinate should stay at the same latitude and the same distance from Sun center
+    assert_quantity_allclose(result2.lat, other.lat)
+    assert_quantity_allclose(result2.radius, other.radius)
+
+
+def test_transform_with_sun_center_reset():
+    # This test sequence ensures that the context manager resets propoerly
+
+    sun_center = SkyCoord(0*u.deg, 0*u.deg, 0*u.AU,
+                          frame=HeliographicStonyhurst(obstime="2001-01-01"))
+    end_frame = HeliocentricInertial(obstime="2001-02-01")
+
+    # Without the context manager, the coordinate should not point at Sun center
+    result1 = sun_center.transform_to(end_frame)
+    assert result1.lon != sun_center.lon
+    assert result1.lat != sun_center.lat
+    assert result1.distance != sun_center.radius
+
+    # Using the context manager, the coordinate should point at Sun center
+    with transform_with_sun_center():
+        result2 = sun_center.transform_to(end_frame)
+    assert_quantity_allclose(result2.lon, sun_center.lon)
+    assert_quantity_allclose(result2.lat, sun_center.lat)
+    assert_quantity_allclose(result2.distance, sun_center.radius)
+
+    # Exiting a nested context manager should not affect the outer context manager
+    with transform_with_sun_center():
+        with transform_with_sun_center():
+            pass
+        result2a = sun_center.transform_to(end_frame)
+    assert_quantity_allclose(result2a.lon, result2.lon)
+    assert_quantity_allclose(result2a.lat, result2.lat)
+    assert_quantity_allclose(result2a.distance, result2.distance)
+
+    # After the context manager, the coordinate should have the same result as the first transform
+    result3 = sun_center.transform_to(end_frame)
+    assert_quantity_allclose(result3.lon, result1.lon)
+    assert_quantity_allclose(result3.lat, result1.lat)
+    assert_quantity_allclose(result3.distance, result1.distance)
