@@ -203,8 +203,10 @@ def test_rsun_meters(generic_map):
 
 
 def test_rsun_obs(generic_map):
-    with pytest.warns(SunpyUserWarning, match='Missing metadata for solar radius'):
-        assert generic_map.rsun_obs == sun.angular_radius(generic_map.date)
+    with pytest.warns(SunpyUserWarning,
+                      match='Missing metadata for solar angular radius: assuming '
+                      'photospheric limb as seen from observer coordinate.'):
+        assert_quantity_allclose(generic_map.rsun_obs, sun.angular_radius(generic_map.date))
 
 
 def test_coordinate_system(generic_map):
@@ -582,8 +584,11 @@ def test_resample_metadata(generic_map, sample_method, new_dimensions):
     with pytest.warns(SunpyUserWarning, match='Missing metadata for observer'):
         assert resampled_map.meta['crval1'] == generic_map.center.Tx.value
         assert resampled_map.meta['crval2'] == generic_map.center.Ty.value
+        assert resampled_map.meta['naxis1'] == new_dimensions[0].value
+        assert resampled_map.meta['naxis2'] == new_dimensions[1].value
     for key in generic_map.meta:
-        if key not in ('cdelt1', 'cdelt2', 'crpix1', 'crpix2', 'crval1', 'crval2'):
+        if key not in ('cdelt1', 'cdelt2', 'crpix1', 'crpix2', 'crval1',
+                       'crval2', 'naxis1', 'naxis2'):
             assert resampled_map.meta[key] == generic_map.meta[key]
 
 
