@@ -1,3 +1,4 @@
+import warnings
 from functools import partial
 from itertools import product
 
@@ -7,13 +8,16 @@ import matplotlib.backend_bases as mback
 import matplotlib.pyplot as plt
 import numpy as np
 import pytest
-import astropy.wcs
+
 import astropy.units as u
+import astropy.wcs
 
 import sunpy.data.test
-from sunpy.time import parse_time
+import sunpy.map
 from sunpy.tests.helpers import figure_test
-from sunpy.visualization.animator import ArrayAnimator, BaseFuncAnimator, LineAnimator, ImageAnimatorWCS, base
+from sunpy.time import parse_time
+from sunpy.util.exceptions import SunpyDeprecationWarning
+from sunpy.visualization.animator import ArrayAnimator, BaseFuncAnimator, ImageAnimatorWCS, LineAnimator, base
 
 
 class FuncAnimatorTest(BaseFuncAnimator):
@@ -100,6 +104,7 @@ def test_base_func_init(fig, colorbar, buttons):
     tfa._mouse_click(event)
     assert tfa.active_slider == 0
 
+
 @pytest.fixture
 def funcanimator():
     data = np.random.random((3, 10, 10))
@@ -148,16 +153,16 @@ axis_ranges1 = np.tile(np.linspace(0, 100, 21), (10, 1))
 
 @pytest.mark.parametrize('axis_ranges, exp_extent, exp_axis_ranges',
                          [([None, None], [-0.5, 19.5],
-                          [np.arange(10), np.array([-0.5, 19.5])]),
+                           [np.arange(10), np.array([-0.5, 19.5])]),
 
                           ([[0, 10], [0, 20]], [0, 20],
-                          [np.arange(0.5, 10.5), np.asarray([0, 20])]),
+                           [np.arange(0.5, 10.5), np.asarray([0, 20])]),
 
                           ([np.arange(0, 11), np.arange(0, 21)], [0, 20],
-                          [np.arange(0.5, 10.5), np.arange(0.5, 20.5)]),
+                           [np.arange(0.5, 10.5), np.arange(0.5, 20.5)]),
 
                           ([None, axis_ranges1], [0.0, 100.0],
-                          [np.arange(10), base.edges_to_centers_nd(axis_ranges1, 1)])])
+                           [np.arange(10), base.edges_to_centers_nd(axis_ranges1, 1)])])
 def test_sanitize_axis_ranges(axis_ranges, exp_extent, exp_axis_ranges):
     data_shape = (10, 20)
     data = np.random.rand(*data_shape)
@@ -165,8 +170,9 @@ def test_sanitize_axis_ranges(axis_ranges, exp_extent, exp_axis_ranges):
     out_axis_ranges, out_extent = aanim._sanitize_axis_ranges(axis_ranges=axis_ranges,
                                                               data_shape=data_shape)
     assert exp_extent == out_extent
-    assert np.array_equal(exp_axis_ranges[0], out_axis_ranges[0])
     assert np.array_equal(exp_axis_ranges[1], out_axis_ranges[1])
+    assert callable(out_axis_ranges[0])
+    assert np.array_equal(exp_axis_ranges[0], out_axis_ranges[0](np.arange(10)))
 
 
 xdata = np.tile(np.linspace(0, 100, 11), (5, 5, 1))
@@ -188,10 +194,12 @@ def test_lineanimator_figure():
     data0 = np.random.rand(*data_shape0)
     plot_axis0 = 1
     slider_axis0 = 0
-    xdata = np.tile(np.linspace(0, 100, (data_shape0[plot_axis0] + 1)), (data_shape0[slider_axis0], 1))
-    fig = plt.figure()
-    ani = LineAnimator(data0, plot_axis_index=plot_axis0, axis_ranges=[None, xdata], fig=fig)
-    ani.plot_start_image(ax=fig.gca())
+    xdata = np.tile(np.linspace(
+        0, 100, (data_shape0[plot_axis0] + 1)), (data_shape0[slider_axis0], 1))
+
+    ani = LineAnimator(data0, plot_axis_index=plot_axis0, axis_ranges=[None, xdata])
+
+    return ani.fig
 
 
 @figure_test
@@ -204,7 +212,11 @@ def test_imageanimator_figure():
                       for n, key in product([1, 2], ['CTYPE', 'CUNIT', 'CDELT'])}
     t0, t1 = map(parse_time, [k['date-obs'] for k in map_seuence.all_meta()])
     time_diff = (t1 - t0).to(u.s)
-    wcs_input_dict.update({'CTYPE1': 'Time', 'CUNIT1': time_diff.unit.name, 'CDELT1': time_diff.value})
+    wcs_input_dict.update(
+        {'CTYPE1': 'Time', 'CUNIT1': time_diff.unit.name, 'CDELT1': time_diff.value})
     wcs = astropy.wcs.WCS(wcs_input_dict)
-    wcs_anim = ImageAnimatorWCS(sequence_array, wcs=wcs, vmax=1000, image_axes=[0, 1])
-    plt.show()
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", SunpyDeprecationWarning)
+        wcs_anim = ImageAnimatorWCS(sequence_array, wcs=wcs, vmax=1000, image_axes=[0, 1])
+
+    return wcs_anim.fig
